<!-- Fill in the information below before opening an issue. -->

#### Problem description
<!-- Provide a clear and concise description of the issue. -->

#### Example
<!-- Provide a link or minimal code snippet that demonstrates the issue. -->
```python
import riskparityportfolio
# insert code here ...
```

#### Expected behavior
<!-- Describe the behavior you expected and how it differs from the behavior observed in the example. -->

#### Environment:
- platform (e.g. Linux, OSX, Windows):
- riskparityportfolio version (e.g. 1.1):
- installation method (e.g. pip, source):
